"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const Config = require("webpack-chain");
const merge = require("webpack-merge");
const paths_1 = require("./config/paths");
const options_1 = require("./options");
const scripts_1 = require("./scripts");
const webpackMerge = merge;
class Service {
    constructor() {
        this.webpackChainFns = [];
        this.webpackRawConfigFns = [];
        this.script = new scripts_1.default(this);
        this.resolveWebpackConfig = (webpackConfig = {}, isServer, args) => {
            const chainableConfig = this.resolveChainableWebpackConfig(isServer, args);
            let config = chainableConfig.toConfig();
            const original = config;
            config = webpackMerge(webpackConfig, original);
            this.webpackRawConfigFns.forEach((fn) => {
                if (typeof fn === 'function') {
                    config = fn({ isServer, args }, config);
                }
                else if (fn instanceof Object) {
                    config = webpackMerge(config, fn);
                }
            });
            if (config !== original) {
                cloneRuleNames(config.module && config.module.rules, original.module && original.module.rules);
            }
            return config;
        };
        this.run = (command, args) => {
            this.projectOptions = options_1.getOptions(this.getUserOptions(), args);
            if (this.projectOptions.chainWebpack) {
                this.webpackChainFns.push(this.projectOptions.chainWebpack);
            }
            if (this.projectOptions.plugins instanceof Array) {
                this.projectOptions.plugins.forEach((plugin) => {
                    if (typeof plugin === 'string') {
                        const completePluginName = `radish-plugin-${plugin}`;
                        const fn = require(`${process.cwd()}/node_modules/${completePluginName}`).default;
                        if (fn) {
                            this.webpackRawConfigFns.push(fn);
                        }
                        else {
                            throw new Error(`Unable to find '${completePluginName}`);
                        }
                    }
                    else if (typeof plugin === 'function') {
                        this.webpackRawConfigFns.push(plugin);
                    }
                });
            }
            if (this.projectOptions.configureWebpack) {
                this.webpackRawConfigFns.push(this.projectOptions.configureWebpack);
            }
            this.script.run(command, args);
        };
        this.create = (projectName, args) => {
            this.script.create(projectName, args);
        };
        this.getUserOptions = () => {
            if (fs.existsSync(paths_1.default.appConfig)) {
                try {
                    const config = require(paths_1.default.appConfig);
                    return config;
                }
                catch (e) {
                    console.error('Invalid config.js file.', e);
                    process.exit(1);
                }
            }
        };
    }
    resolveChainableWebpackConfig(isServer, args) {
        const chainableConfig = new Config();
        // apply chains
        this.webpackChainFns.forEach(fn => fn({ isServer, args }, chainableConfig));
        return chainableConfig;
    }
}
exports.default = Service;
function cloneRuleNames(to, from) {
    if (!to || !from) {
        return;
    }
    from.forEach((r, i) => {
        if (to[i]) {
            Object.defineProperty(to[i], '__ruleNames', {
                value: r.__ruleNames
            });
            cloneRuleNames(to[i].oneOf, r.oneOf);
        }
    });
}
//# sourceMappingURL=Service.js.map