"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const paths_1 = require("./paths");
const NODE_ENV = process.env.NODE_ENV;
if (!NODE_ENV) {
    throw new Error('The NODE_ENV environment variable is required but was not specified.');
}
const REACT_APP = /^REACT_APP_/i;
exports.getEnv = (isServer, options, publicUrl) => {
    const raw = Object.keys(process.env)
        .filter(key => REACT_APP.test(key))
        .reduce((env, key) => {
        env[key] = process.env[key];
        return env;
    }, {
        NODE_ENV: process.env.NODE_ENV,
        PORT: options.port,
        HOST: options.host,
        SSR: String(options.ssr),
        BUILD_TARGET: isServer ? 'server' : 'client',
        CLIENT_PUBLIC_PATH: process.env.CLIENT_PUBLIC_PATH,
        PUBLIC_URL: publicUrl,
        APP_PUBLIC_DIR: paths_1.default.appBuildPublic,
    });
    process.env = Object.assign({}, process.env, raw);
    const stringified = {
        'process.env': Object.keys(process.env).reduce((env, key) => {
            env[key] = JSON.stringify(raw[key]);
            return env;
        }, {}),
    };
    return {
        stringified,
        raw: Object.assign({}, process.env),
    };
};
//# sourceMappingURL=env.js.map