"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const CaseSensitivePathPlugin = require("case-sensitive-paths-webpack-plugin");
const FriendlyErrorsWebpackPlugin = require("friendly-errors-webpack-plugin");
const fs = require("fs");
const HardSourceWebpackPlugin = require("hard-source-webpack-plugin");
const path = require("path");
const tsconfig_paths_webpack_plugin_1 = require("tsconfig-paths-webpack-plugin");
const webpack = require("webpack");
const WebpackBar = require("webpackbar");
const WriteFilePlugin = require('write-file-webpack-plugin');
const CircularDependencyPlugin = require('circular-dependency-plugin');
const paths_1 = require("../paths");
const env_1 = require("../env");
const script_1 = require("./loader/script");
const style_1 = require("./loader/style");
const appDirectory = fs.realpathSync(process.cwd());
const nodePath = (process.env.NODE_PATH || '')
    .split(path.delimiter)
    .filter(folder => folder && !path.isAbsolute(folder))
    .map(folder => path.resolve(appDirectory, folder))
    .join(path.delimiter);
const dev = process.env.NODE_ENV === 'development';
exports.default = (isServer, service, args) => {
    const { projectOptions } = service;
    const { hardSource, ssr } = projectOptions;
    const dotenv = env_1.getEnv(isServer, projectOptions, '');
    const webpackMode = process.env.NODE_ENV;
    let webpackConfig = {
        mode: webpackMode,
        devtool: 'source-map',
        context: process.cwd(),
        cache: true,
        output: {
            publicPath: ssr ? '/public/' : '/',
            hotUpdateChunkFilename: 'static/webpack/[id].[hash].hot-update.js',
            hotUpdateMainFilename: 'static/webpack/[hash].hot-update.json',
        },
        optimization: !dev ? {
            splitChunks: {
                cacheGroups: {
                    commons: {
                        test: /[\\/]node_modules[\\/]/,
                        name: 'vendor',
                        chunks: 'all'
                    }
                }
            }
        } : {},
        resolveLoader: {
            modules: [
                path.resolve(__dirname, '../../../node_modules'),
                paths_1.default.appNodeModules,
            ],
        },
        resolve: {
            extensions: ['.wasm', '.mjs', '.js', '.jsx', '.ts', '.tsx', '.json'],
            alias: {
                'webpack-hot-middleware/client': require.resolve('webpack-hot-middleware/client'),
            },
            modules: [
                path.resolve(__dirname, '../../../../node_modules'),
                paths_1.default.appNodeModules,
            ].concat(
            // It is guaranteed to exist because we tweak it in `env.js`
            nodePath.split(path.delimiter).filter(Boolean)),
            plugins: [
                new tsconfig_paths_webpack_plugin_1.default({
                // configFile: paths.appTsconfig
                }),
            ],
        },
        module: {
            rules: [
                {
                    oneOf: [
                        style_1.default({ isServer }),
                        script_1.default({ isServer }),
                        {
                            test: [/\.bmp$/, /\.gif$/, /\.jpe?g$/, /\.png$/],
                            loader: require.resolve('url-loader'),
                            options: {
                                limit: 10000,
                                name: 'static/media/[name].[hash:8].[ext]',
                            },
                        },
                        {
                            exclude: [/\.(js|jsx|mjs|tsx?)$/, /\.html$/, /\.json$/],
                            loader: require.resolve('file-loader'),
                            options: {
                                name: 'static/media/[name].[hash:8].[ext]',
                            },
                        },
                    ]
                }
            ],
        },
        plugins: [
            new CircularDependencyPlugin({
                exclude: /node_modules/
            }),
            new webpack.DefinePlugin(dotenv.stringified),
            new webpack.NamedModulesPlugin(),
            new WebpackBar({
                minimal: false,
                compiledIn: false,
                // profile: true,
                name: isServer ? 'server' : 'client',
            }),
            dev && hardSource && new HardSourceWebpackPlugin(),
            dev && new FriendlyErrorsWebpackPlugin(),
            dev && new webpack.HotModuleReplacementPlugin(),
            dev && new CaseSensitivePathPlugin(),
            dev && ssr && new WriteFilePlugin({
                exitOnErrors: false,
                log: false,
                // required not to cache removed files
                useHashIndex: false,
            }),
        ].filter(Boolean)
    };
    webpackConfig = service.resolveWebpackConfig(webpackConfig, isServer, args);
    return webpackConfig;
};
//# sourceMappingURL=base.js.map