"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const CopyWebpackPlugin = require("copy-webpack-plugin");
const HtmlWebpackPlugin = require("html-webpack-plugin");
const MiniCssExtractPlugin = require("mini-css-extract-plugin");
const OptimizeCssAssetsWebpackPlugin = require("optimize-css-assets-webpack-plugin");
const path = require("path");
const webpack_1 = require("react-loadable/webpack");
const SWPrecacheWebpackPlugin = require("sw-precache-webpack-plugin");
const webpack_bundle_analyzer_1 = require("webpack-bundle-analyzer");
const ManifestPlugin = require("webpack-manifest-plugin");
const merge = require("webpack-merge");
const paths_1 = require("../paths");
const base_1 = require("./base");
const AutoDllPlugin = require('autodll-webpack-plugin');
const ModuleNotFoundPlugin = require('react-dev-utils/ModuleNotFoundPlugin');
const errorOverlayMiddleware = require('react-dev-utils/errorOverlayMiddleware');
const InterpolateHtmlPlugin = require('react-dev-utils/InterpolateHtmlPlugin');
const CaseSensitivePathsPlugin = require('case-sensitive-paths-webpack-plugin');
const WatchMissingNodeModulesPlugin = require('react-dev-utils/WatchMissingNodeModulesPlugin');
const dev = process.env.NODE_ENV === 'development';
exports.default = (service, args) => {
    const { projectOptions } = service;
    const { host, clientIndexJs, autoDll, devPort, proxy, analyze, ssr } = projectOptions;
    const clientConfig = {
        entry: [
            dev && `webpack-dev-server/client?http://${host}:${devPort}`,
            dev && 'webpack/hot/only-dev-server',
            dev && 'react-hot-loader/patch',
            clientIndexJs
        ].filter(Boolean),
        output: {
            path: path.join(paths_1.default.appBuildSrc, ''),
            filename: 'static/chunks/app.[hash].js',
            libraryTarget: 'jsonp',
            chunkFilename: 'static/chunks/[name].[contenthash].js',
        },
        devServer: {
            proxy,
            quiet: true,
            compress: true,
            host: process.env.HOST,
            port: devPort,
            historyApiFallback: {
                disableDotRule: true
            },
            watchOptions: {
                ignored: /node_modules/,
            },
            inline: true,
            hot: true,
            overlay: true,
            clientLogLevel: 'none',
            contentBase: paths_1.default.appBuildSrc,
            publicPath: ssr ? '/__server' : '/',
            before(app) {
                app.use(errorOverlayMiddleware());
            },
        },
        plugins: [
            !dev && new OptimizeCssAssetsWebpackPlugin({
                cssProcessorOptions: {
                    safe: true,
                    discardComments: {
                        removeAll: true
                    }
                }
            }),
            !ssr && new HtmlWebpackPlugin({
                inject: true,
                template: paths_1.default.appHtml,
            }),
            !ssr && new InterpolateHtmlPlugin(HtmlWebpackPlugin, {
                PUBLIC_URL: ''
            }),
            dev && ssr && new AutoDllPlugin({
                debug: true,
                inject: true,
                filename: '[name].js',
                entry: {
                    vendor: autoDll.vendor || [],
                    polyfills: autoDll.polyfills || [],
                }
            }),
            ssr && new webpack_1.ReactLoadablePlugin({
                filename: path.join(paths_1.default.appBuildSrc, 'react-loadable.json'),
            }),
            ssr && new ManifestPlugin({
                fileName: 'asset-manifest.json',
                writeToFileEmit: true
            }),
            new MiniCssExtractPlugin({
                filename: 'static/style/[name].css',
                chunkFilename: 'static/style/[id].css',
            }),
            new CopyWebpackPlugin([{
                    from: paths_1.default.appPublic,
                }]),
            new SWPrecacheWebpackPlugin({
                cacheId: 'client',
                dontCacheBustUrlsMatching: false,
                filename: 'service-worker.js',
                minify: true,
            }),
            analyze && new webpack_bundle_analyzer_1.BundleAnalyzerPlugin({
                defaultSizes: 'gzip',
                generateStatsFile: true,
            }),
            new ModuleNotFoundPlugin(paths_1.default.appPath),
            new CaseSensitivePathsPlugin(),
            new WatchMissingNodeModulesPlugin(paths_1.default.appNodeModules),
        ].filter(Boolean)
    };
    return merge(base_1.default(false, service, args), clientConfig);
};
//# sourceMappingURL=client.js.map