"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const webpack = require("webpack");
const merge = require("webpack-merge");
const StartServerPlugin = require('start-server-webpack-plugin');
const paths_1 = require("../paths");
const base_1 = require("./base");
const dev = process.env.NODE_ENV === 'development';
exports.default = (service, args) => {
    const serverConfig = {
        name: 'server',
        target: 'node',
        entry: [
            dev && 'webpack/hot/poll?1000',
            service.projectOptions.serverIndexJs
        ].filter(Boolean),
        node: {
            __console: false,
            __dirname: false,
            __filename: false,
        },
        output: {
            path: path.join(paths_1.default.appBuildSrc, 'server'),
            filename: 'server.js',
            libraryTarget: 'commonjs2',
            chunkFilename: '[name].[contenthash].js'
        },
        plugins: [
            new webpack.optimize.LimitChunkCountPlugin({
                maxChunks: 1,
            }),
            new webpack.BannerPlugin({
                banner: `require("source-map-support").install();`,
                entryOnly: false,
                include: [
                    'server.js',
                ],
                raw: true,
            }),
            dev && new StartServerPlugin({
                name: 'server.js',
                nodeArgs: ['-r', require.resolve('source-map-support/register')],
            }),
            dev && new webpack.WatchIgnorePlugin([paths_1.default.assetManifest, paths_1.default.assetLoadable])
        ].filter(Boolean)
    };
    return merge(base_1.default(true, service, args), serverConfig);
};
//# sourceMappingURL=server.js.map