"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const fs = require("fs-extra");
const webpack = require("webpack");
const paths_1 = require("../config/paths");
const client_1 = require("../config/webpack/client");
const server_1 = require("../config/webpack/server");
const FileSizeReporter = require('react-dev-utils/FileSizeReporter');
const formatWebpackMessages = require('react-dev-utils/formatWebpackMessages');
const printBuildError = require('react-dev-utils/printBuildError');
const measureFileSizesBeforeBuild = FileSizeReporter.measureFileSizesBeforeBuild;
const printFileSizesAfterBuild = FileSizeReporter.printFileSizesAfterBuild;
const WARN_AFTER_BUNDLE_GZIP_SIZE = 512 * 1024;
const WARN_AFTER_CHUNK_GZIP_SIZE = 1024 * 1024;
exports.default = (service, args) => __awaiter(this, void 0, void 0, function* () {
    const fileSizes = yield measureFileSizesBeforeBuild(paths_1.default.appBuild);
    fs.emptyDirSync(paths_1.default.appBuild);
    build(fileSizes, service, args)
        .then(({ stats, previousFileSizes, warnings }) => {
        if (warnings.length) {
            console.log(chalk_1.default.yellow('Compiled with warnings.\n'));
            console.log(warnings.join('\n\n'));
            console.log(
            // tslint:disable-next-line:prefer-template
            '\nSearch for the ' +
                chalk_1.default.underline(chalk_1.default.yellow('keywords')) +
                ' to learn more about each warning.');
            console.log(
            // tslint:disable-next-line:prefer-template
            'To ignore, add ' +
                chalk_1.default.cyan('// eslint-disable-next-line') +
                ' to the line before.\n');
        }
        else {
            console.log(chalk_1.default.green('Compiled successfully.\n'));
        }
        console.log('File sizes after gzip:\n');
        printFileSizesAfterBuild(stats, previousFileSizes, paths_1.default.appBuild, WARN_AFTER_BUNDLE_GZIP_SIZE, WARN_AFTER_CHUNK_GZIP_SIZE);
        console.log();
        console.log(chalk_1.default.green('build successfully.\n'));
    })
        .catch((err) => {
        console.log(chalk_1.default.red('Failed to compile.\n'));
        printBuildError(err);
        process.exit(1);
    });
});
const build = (previousFileSizes, service, args) => __awaiter(this, void 0, void 0, function* () {
    const { projectOptions } = service;
    const { ssr } = projectOptions;
    const clientConfig = client_1.default(service, args);
    const serverConfig = server_1.default(service, args);
    const clientMultiCompiler = webpack(clientConfig);
    const serverMultiCompiler = webpack(serverConfig);
    const promiseArr = [
        webpackCompiler(clientMultiCompiler)
    ];
    if (ssr) {
        promiseArr.push(webpackCompiler(serverMultiCompiler));
    }
    const [data] = yield Promise.all(promiseArr);
    return Object.assign({ previousFileSizes, config: clientConfig }, data);
});
function webpackCompiler(compiler) {
    return new Promise((resolve, reject) => {
        compiler.run((err, stats) => {
            let messages;
            if (err) {
                if (!err.message) {
                    return reject(err);
                }
                messages = formatWebpackMessages({
                    errors: [err.message],
                    warnings: [],
                });
            }
            else {
                messages = formatWebpackMessages(stats.toJson({ all: false, warnings: true, errors: true }));
            }
            if (messages.errors.length) {
                // Only keep the first error. Others are often indicative
                // of the same problem, but confuse the reader with noise.
                if (messages.errors.length > 1) {
                    messages.errors.length = 1;
                }
                return reject(new Error(messages.errors.join('\n\n')));
            }
            const resolveArgs = {
                stats,
                warnings: messages.warnings,
            };
            return resolve(resolveArgs);
        });
    });
}
//# sourceMappingURL=build.js.map